@@ -39,6 +39,9 @@ private slots:
     void on_btnClose_pressed();
     void on_btnSave_pressed();
     void on_btnClear_pressed();
+    void on_btnApply_clicked();
+    void on_btnSave_clicked();
+    void on_btnSav_clicked();
 };
 
 #endif // MAINWINDOW_H
